@@ -1,6 +1,6 @@
 package Number::Phone::Country::Data;
 
-$VERSION = '1.3';
+$VERSION = '1.4';
 %Number::Phone::Country::idd_codes = (
     # 1     => 'NANP',
 
@@ -71,13 +71,18 @@ $VERSION = '1.3';
     441624 => 'IM', 447624 => 'IM', 447524 => 'IM', 447924 => 'IM',
 
     # 5* checked against wtng.info 2011-07-08
-    500     => 'FK',
+    # GS apparently shares (according to wikipedia) +500 with FK, but it's
+    # unknown whether it actually has any phone service at all or whether
+    # the handful of people there just use sat-phones
+    500     => ['FK', 'GS'],
     501     => 'BZ', 502     => 'GT', 503     => 'SV', 504     => 'HN',
     505     => 'NI', 506     => 'CR', 507     => 'PA',
     508     => 'PM', 509     => 'HT',
     51      => 'PE', 52      => 'MX', 53      => 'CU', 54      => 'AR',
     55      => 'BR', 56      => 'CL', 57      => 'CO', 58      => 'VE',
-    590     => 'GP', 591     => 'BO', 592     => 'GY', 593     => 'EC',
+    # http://en.wikipedia.org/wiki/Telephone_numbers_in_France#Overseas_Departments_and_Territories
+    590     => ['GP', 'BL', 'MF'],
+    591     => 'BO', 592     => 'GY', 593     => 'EC',
     594     => 'GF', 595     => 'PY', 596     => ['MQ', 'TF'], 597     => 'SR',
     598     => 'UY',
     599     => 'BQ',
@@ -125,7 +130,7 @@ $VERSION = '1.3';
     976     => 'MN', 977     => 'NP',
     98      => 'IR',
     992     => 'TJ',
-    993     => 'TM', 994     => 'AZ', 995     => ['GE', 'GS'],
+    993     => 'TM', 994     => 'AZ', 995     => 'GE',
     996     => 'KG', 998     => 'UZ',
 
     # these checked against wtng.info 2011-07-08
@@ -197,6 +202,7 @@ $VERSION = '1.3';
     'BH' => ['973',   '00',  undef], # Bahrain
     'BI' => ['257',   '00',  undef], # Burundi
     'BJ' => ['229',   '00',  undef], # Benin
+    'BL' => ['590',   '00',  undef], # Saint Barthélemy
     'BM' => [  '1',  '011',    '1'], # Bermuda
     'BN' => ['673',   '00',    '0'], # Brunei Darussalam
     'BO' => ['591',   '00',    '0'], # Bolivia
@@ -247,7 +253,7 @@ $VERSION = '1.3';
     'GA' => ['241',   '00',  undef], # Gabonese Republic
     'GB' => [ '44',   '00',    '0'], # United Kingdom
     'GD' => [  '1',  '011',    '4'], # Grenada
-    'GE' => ['995',  '810',    '8'], # Georgia
+    'GE' => ['995',   '00',    '0'], # Georgia
     'GF' => ['594',   '00',  undef], # French Guiana
     'GG' => [ '44',   '00',    '0'], # Guernsey
     'GH' => ['233',   '00',  undef], # Ghana
@@ -258,7 +264,7 @@ $VERSION = '1.3';
     'GP' => ['590',   '00',  undef], # Guadeloupe
     'GQ' => ['240',   '00',  undef], # Equatorial Guinea
     'GR' => [ '30',   '00',  undef], # Greece
-    'GS' => ['995',  '810',    '8'], # South Georgia and the South Sandwich Islands (IDD really 8**10)
+    'GS' => ['500',   '00',  undef], # South Georgia and the South Sandwich Islands
     'GT' => ['502',   '00',  undef], # Guatemala
     'GU' => [  '1',  '011',    '1'], # Guam
     'GW' => ['245',   '00',  undef], # Guinea-Bissau
@@ -303,12 +309,13 @@ $VERSION = '1.3';
     'LS' => ['266',   '00',    '0'], # Lesotho
     'LT' => ['370',   '00',    '8'], # Lithuania
     'LU' => ['352',   '00',  undef], # Luxembourg
-    'LV' => ['371',   '00',    '8'], # Latvia
+    'LV' => ['371',   '00',  undef], # Latvia
     'LY' => ['218',   '00',    '0'], # Libyan Arab Jamahiriya
     'MA' => ['212',   '00',  undef], # Morocco
     'MC' => ['377',   '00',    '0'], # Monaco
     'MD' => ['373',   '00',    '0'], # Moldova, Republic of
     'ME' => ['382',   '99',    '0'], # Montenegro
+    'MF' => ['590',   '00',  undef], # Saint Martin
     'MG' => ['261',   '00',    '0'], # Madagascar
     'MH' => ['692',  '011',    '1'], # Marshall Islands
     'MK' => ['389',   '00',    '0'], # Macedonia, the Former Yugoslav Republic of
@@ -397,7 +404,7 @@ $VERSION = '1.3';
     'TV' => ['688',   '00',  undef], # Tuvalu
     'TW' => ['886',  '002',  undef], # Taiwan, Province of China
     'TZ' => ['255',  '000',    '0'], # Tanzania, United Republic of
-    'UA' => ['380',  '810',    '8'], # Ukraine (IDD really 8**10)
+    'UA' => ['380',   '00',    '0'], # Ukraine
     'UG' => ['256',  '000',    '0'], # Uganda
     'US' => [  '1',  '011',    '1'], # United States
     'UY' => ['598',   '00',    '0'], # Uruguay
